# rbi_ml

Helps build better ml workflow with...   
* `kedro` for data engineering on pyspark and databricks,  
* `pytorch-lightning` for model training,  
* `wandb` and `mlflow` for experiment tracking and management,  
* Other utility tools to help handle aws services and miscellaneous tasks

Source code can be found here: https://gitlab.com/rbibigdata/mldp/rbi-ml/-/tree/rbi_ml_package